"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_disaster_recovery_api import ConfigurationDisasterRecoveryApi  # noqa: E501


class TestConfigurationDisasterRecoveryApi(unittest.TestCase):
    """ConfigurationDisasterRecoveryApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDisasterRecoveryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate(self):
        """Test case for activate

        """
        pass

    def test_delete(self):
        """Test case for delete

        """
        pass

    def test_delete_dc(self):
        """Test case for delete_dc

        """
        pass

    def test_delete_local_dc(self):
        """Test case for delete_local_dc

        """
        pass

    def test_disaster_recovery_pause_replication(self):
        """Test case for disaster_recovery_pause_replication

        """
        pass

    def test_disaster_recovery_replication_request(self):
        """Test case for disaster_recovery_replication_request

        """
        pass

    def test_disaster_recovery_un_pause_replication(self):
        """Test case for disaster_recovery_un_pause_replication

        """
        pass

    def test_download(self):
        """Test case for download

        """
        pass

    def test_download_replication_data(self):
        """Test case for download_replication_data

        """
        pass

    def test_get(self):
        """Test case for get

        """
        pass

    def test_get_cluster_info(self):
        """Test case for get_cluster_info

        """
        pass

    def test_get_config_db_restore_status(self):
        """Test case for get_config_db_restore_status

        """
        pass

    def test_get_details(self):
        """Test case for get_details

        """
        pass

    def test_get_disaster_recovery_local_replication_schedule(self):
        """Test case for get_disaster_recovery_local_replication_schedule

        """
        pass

    def test_get_disaster_recovery_status(self):
        """Test case for get_disaster_recovery_status

        """
        pass

    def test_get_history(self):
        """Test case for get_history

        """
        pass

    def test_get_local_data_center_state(self):
        """Test case for get_local_data_center_state

        """
        pass

    def test_get_local_history(self):
        """Test case for get_local_history

        """
        pass

    def test_get_reachability_info(self):
        """Test case for get_reachability_info

        """
        pass

    def test_get_remote_data_center_state(self):
        """Test case for get_remote_data_center_state

        """
        pass

    def test_get_remote_data_center_version(self):
        """Test case for get_remote_data_center_version

        """
        pass

    def test_get_remote_dc_members_state(self):
        """Test case for get_remote_dc_members_state

        """
        pass

    def test_getdr_status(self):
        """Test case for getdr_status

        """
        pass

    def test_pause_dr(self):
        """Test case for pause_dr

        """
        pass

    def test_pause_local_arbitrator(self):
        """Test case for pause_local_arbitrator

        """
        pass

    def test_pause_local_dc_for_dr(self):
        """Test case for pause_local_dc_for_dr

        """
        pass

    def test_pause_local_dc_replication(self):
        """Test case for pause_local_dc_replication

        """
        pass

    def test_register(self):
        """Test case for register

        """
        pass

    def test_restart_data_center(self):
        """Test case for restart_data_center

        """
        pass

    def test_restore_config_db(self):
        """Test case for restore_config_db

        """
        pass

    def test_unpause_dr(self):
        """Test case for unpause_dr

        """
        pass

    def test_unpause_local_arbitrator(self):
        """Test case for unpause_local_arbitrator

        """
        pass

    def test_unpause_local_dc_for_dr(self):
        """Test case for unpause_local_dc_for_dr

        """
        pass

    def test_unpause_local_dc_replication(self):
        """Test case for unpause_local_dc_replication

        """
        pass

    def test_update(self):
        """Test case for update

        """
        pass

    def test_update1(self):
        """Test case for update1

        """
        pass

    def test_update_disaster_recovery_state(self):
        """Test case for update_disaster_recovery_state

        """
        pass

    def test_update_disaster_recovery_state1(self):
        """Test case for update_disaster_recovery_state1

        """
        pass

    def test_update_dr_state(self):
        """Test case for update_dr_state

        """
        pass

    def test_update_replication(self):
        """Test case for update_replication

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_system_status_stats_api import MonitoringSystemStatusStatsApi  # noqa: E501


class TestMonitoringSystemStatusStatsApi(unittest.TestCase):
    """MonitoringSystemStatusStatsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringSystemStatusStatsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_aggregation_data_by_query17(self):
        """Test case for get_aggregation_data_by_query17

        """
        pass

    def test_get_count19(self):
        """Test case for get_count19

        """
        pass

    def test_get_count_post19(self):
        """Test case for get_count_post19

        """
        pass

    def test_get_post_aggregation_app_data_by_query16(self):
        """Test case for get_post_aggregation_app_data_by_query16

        """
        pass

    def test_get_post_aggregation_data_by_query16(self):
        """Test case for get_post_aggregation_data_by_query16

        """
        pass

    def test_get_post_stat_bulk_raw_data17(self):
        """Test case for get_post_stat_bulk_raw_data17

        """
        pass

    def test_get_stat_bulk_raw_data17(self):
        """Test case for get_stat_bulk_raw_data17

        """
        pass

    def test_get_stat_data_fields19(self):
        """Test case for get_stat_data_fields19

        """
        pass

    def test_get_stat_data_raw_data16(self):
        """Test case for get_stat_data_raw_data16

        """
        pass

    def test_get_stat_data_raw_data_as_csv17(self):
        """Test case for get_stat_data_raw_data_as_csv17

        """
        pass

    def test_get_stat_query_fields19(self):
        """Test case for get_stat_query_fields19

        """
        pass

    def test_get_stats_raw_data17(self):
        """Test case for get_stats_raw_data17

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_device_details_api import MonitoringDeviceDetailsApi  # noqa: E501


class TestMonitoringDeviceDetailsApi(unittest.TestCase):
    """MonitoringDeviceDetailsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringDeviceDetailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_enable_sdavcon_device(self):
        """Test case for enable_sdavcon_device

        """
        pass

    def test_generate_device_state_data(self):
        """Test case for generate_device_state_data

        """
        pass

    def test_generate_device_state_data_fields(self):
        """Test case for generate_device_state_data_fields

        """
        pass

    def test_generate_device_state_data_with_query_string(self):
        """Test case for generate_device_state_data_with_query_string

        """
        pass

    def test_get_all_device_status(self):
        """Test case for get_all_device_status

        """
        pass

    def test_get_device_counters(self):
        """Test case for get_device_counters

        """
        pass

    def test_get_device_list_as_key_value(self):
        """Test case for get_device_list_as_key_value

        """
        pass

    def test_get_device_models(self):
        """Test case for get_device_models

        """
        pass

    def test_get_device_only_status(self):
        """Test case for get_device_only_status

        """
        pass

    def test_get_device_running_config(self):
        """Test case for get_device_running_config

        """
        pass

    def test_get_device_running_config_html(self):
        """Test case for get_device_running_config_html

        """
        pass

    def test_get_device_tloc_status(self):
        """Test case for get_device_tloc_status

        """
        pass

    def test_get_device_tloc_util(self):
        """Test case for get_device_tloc_util

        """
        pass

    def test_get_device_tloc_util_details(self):
        """Test case for get_device_tloc_util_details

        """
        pass

    def test_get_hardware_health_details(self):
        """Test case for get_hardware_health_details

        """
        pass

    def test_get_hardware_health_summary(self):
        """Test case for get_hardware_health_summary

        """
        pass

    def test_get_stats_queues(self):
        """Test case for get_stats_queues

        """
        pass

    def test_get_sync_queues(self):
        """Test case for get_sync_queues

        """
        pass

    def test_get_unconfigured(self):
        """Test case for get_unconfigured

        """
        pass

    def test_get_v_manage_system_ip(self):
        """Test case for get_v_manage_system_ip

        """
        pass

    def test_get_vedge_inventory(self):
        """Test case for get_vedge_inventory

        """
        pass

    def test_get_vedge_inventory_summary(self):
        """Test case for get_vedge_inventory_summary

        """
        pass

    def test_list_all_device_models(self):
        """Test case for list_all_device_models

        """
        pass

    def test_list_all_devices(self):
        """Test case for list_all_devices

        """
        pass

    def test_list_all_monitor_details_devices(self):
        """Test case for list_all_monitor_details_devices

        """
        pass

    def test_list_currently_syncing_devices(self):
        """Test case for list_currently_syncing_devices

        """
        pass

    def test_list_reachable_devices(self):
        """Test case for list_reachable_devices

        """
        pass

    def test_list_unreachable_devices(self):
        """Test case for list_unreachable_devices

        """
        pass

    def test_remove_unreachable_device(self):
        """Test case for remove_unreachable_device

        """
        pass

    def test_set_block_sync(self):
        """Test case for set_block_sync

        """
        pass

    def test_sync_all_devices_mem_db(self):
        """Test case for sync_all_devices_mem_db

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_feature_profile_sdwan_api import ConfigurationFeatureProfileSDWANApi  # noqa: E501


class TestConfigurationFeatureProfileSDWANApi(unittest.TestCase):
    """ConfigurationFeatureProfileSDWANApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationFeatureProfileSDWANApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_aaa_profile_parcel_for_system(self):
        """Test case for create_aaa_profile_parcel_for_system

        """
        pass

    def test_create_banner_profile_parcel_for_system(self):
        """Test case for create_banner_profile_parcel_for_system

        """
        pass

    def test_create_basic_profile_parcel_for_system(self):
        """Test case for create_basic_profile_parcel_for_system

        """
        pass

    def test_create_bfd_profile_parcel_for_system(self):
        """Test case for create_bfd_profile_parcel_for_system

        """
        pass

    def test_create_cellular_controller_and_cellular_profile_parcel_association_for_transport(self):
        """Test case for create_cellular_controller_and_cellular_profile_parcel_association_for_transport

        """
        pass

    def test_create_cellular_controller_profile_parcel_for_transport(self):
        """Test case for create_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_create_cellular_profile_profile_parcel_for_transport(self):
        """Test case for create_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_create_global_profile_parcel_for_system(self):
        """Test case for create_global_profile_parcel_for_system

        """
        pass

    def test_create_lan_vpn_and_routing_bgp_parcel_association_for_service(self):
        """Test case for create_lan_vpn_and_routing_bgp_parcel_association_for_service

        """
        pass

    def test_create_lan_vpn_and_routing_ospf_parcel_association_for_service(self):
        """Test case for create_lan_vpn_and_routing_ospf_parcel_association_for_service

        """
        pass

    def test_create_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for create_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_create_lan_vpn_interface_ethernet_parcel_for_service(self):
        """Test case for create_lan_vpn_interface_ethernet_parcel_for_service

        """
        pass

    def test_create_lan_vpn_profile_parcel_for_service(self):
        """Test case for create_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_create_logging_profile_parcel_for_system(self):
        """Test case for create_logging_profile_parcel_for_system

        """
        pass

    def test_create_management_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for create_management_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_create_management_vpn_profile_parcel_for_transport(self):
        """Test case for create_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_create_ntp_profile_parcel_for_system(self):
        """Test case for create_ntp_profile_parcel_for_system

        """
        pass

    def test_create_omp_profile_parcel_for_system(self):
        """Test case for create_omp_profile_parcel_for_system

        """
        pass

    def test_create_routing_bgp_profile_parcel_for_service(self):
        """Test case for create_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_create_routing_ospf_profile_parcel_for_service(self):
        """Test case for create_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_create_sdwan_config_profile_parcel_for_cli(self):
        """Test case for create_sdwan_config_profile_parcel_for_cli

        """
        pass

    def test_create_sdwan_feature_profile(self):
        """Test case for create_sdwan_feature_profile

        """
        pass

    def test_create_sdwan_service_feature_profile(self):
        """Test case for create_sdwan_service_feature_profile

        """
        pass

    def test_create_sdwan_system_feature_profile(self):
        """Test case for create_sdwan_system_feature_profile

        """
        pass

    def test_create_sdwan_transport_feature_profile(self):
        """Test case for create_sdwan_transport_feature_profile

        """
        pass

    def test_create_tracker_profile_parcel_for_service(self):
        """Test case for create_tracker_profile_parcel_for_service

        """
        pass

    def test_create_tracker_profile_parcel_for_transport(self):
        """Test case for create_tracker_profile_parcel_for_transport

        """
        pass

    def test_create_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for create_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_create_wan_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for create_wan_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_create_wan_vpn_profile_parcel_for_transport(self):
        """Test case for create_wan_vpn_profile_parcel_for_transport

        """
        pass

    def test_delete_aaa_profile_parcel_for_system(self):
        """Test case for delete_aaa_profile_parcel_for_system

        """
        pass

    def test_delete_banner_profile_parcel_for_system(self):
        """Test case for delete_banner_profile_parcel_for_system

        """
        pass

    def test_delete_basic_profile_parcel_for_system(self):
        """Test case for delete_basic_profile_parcel_for_system

        """
        pass

    def test_delete_bfd_profile_parcel_for_system(self):
        """Test case for delete_bfd_profile_parcel_for_system

        """
        pass

    def test_delete_cellular_controller_and_cellular_profile_association_for_transport(self):
        """Test case for delete_cellular_controller_and_cellular_profile_association_for_transport

        """
        pass

    def test_delete_cellular_controller_profile_parcel_for_transport(self):
        """Test case for delete_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_delete_cellular_profile_profile_parcel_for_transport(self):
        """Test case for delete_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_delete_config_profile_parcel_for_cli(self):
        """Test case for delete_config_profile_parcel_for_cli

        """
        pass

    def test_delete_global_profile_parcel_for_system(self):
        """Test case for delete_global_profile_parcel_for_system

        """
        pass

    def test_delete_lan_vpn_and_routing_bgp_association_for_service(self):
        """Test case for delete_lan_vpn_and_routing_bgp_association_for_service

        """
        pass

    def test_delete_lan_vpn_and_routing_ospf_association_for_service(self):
        """Test case for delete_lan_vpn_and_routing_ospf_association_for_service

        """
        pass

    def test_delete_lan_vpn_interface_ethernet_and_tracker_association_for_transport(self):
        """Test case for delete_lan_vpn_interface_ethernet_and_tracker_association_for_transport

        """
        pass

    def test_delete_lan_vpn_interface_ethernet_for_service(self):
        """Test case for delete_lan_vpn_interface_ethernet_for_service

        """
        pass

    def test_delete_lan_vpn_profile_parcel_for_service(self):
        """Test case for delete_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_delete_logging_profile_parcel_for_system(self):
        """Test case for delete_logging_profile_parcel_for_system

        """
        pass

    def test_delete_management_vpn_interface_ethernet_for_transport(self):
        """Test case for delete_management_vpn_interface_ethernet_for_transport

        """
        pass

    def test_delete_management_vpn_profile_parcel_for_transport(self):
        """Test case for delete_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_delete_ntp_profile_parcel_for_system(self):
        """Test case for delete_ntp_profile_parcel_for_system

        """
        pass

    def test_delete_omp_profile_parcel_for_system(self):
        """Test case for delete_omp_profile_parcel_for_system

        """
        pass

    def test_delete_routing_bgp_profile_parcel_for_service(self):
        """Test case for delete_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_delete_routing_ospf_profile_parcel_for_service(self):
        """Test case for delete_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_delete_sdwan_feature_profile_for_cli(self):
        """Test case for delete_sdwan_feature_profile_for_cli

        """
        pass

    def test_delete_sdwan_service_feature_profile(self):
        """Test case for delete_sdwan_service_feature_profile

        """
        pass

    def test_delete_sdwan_system_feature_profile(self):
        """Test case for delete_sdwan_system_feature_profile

        """
        pass

    def test_delete_sdwan_transport_feature_profile(self):
        """Test case for delete_sdwan_transport_feature_profile

        """
        pass

    def test_delete_tracker_profile_parcel_for_service(self):
        """Test case for delete_tracker_profile_parcel_for_service

        """
        pass

    def test_delete_tracker_profile_parcel_for_transport(self):
        """Test case for delete_tracker_profile_parcel_for_transport

        """
        pass

    def test_delete_wan_vpn_interface_ethernet_and_tracker_association_for_transport(self):
        """Test case for delete_wan_vpn_interface_ethernet_and_tracker_association_for_transport

        """
        pass

    def test_delete_wan_vpn_interface_ethernet_for_transport(self):
        """Test case for delete_wan_vpn_interface_ethernet_for_transport

        """
        pass

    def test_delete_wan_vpn_profile_parcel_for_transport(self):
        """Test case for delete_wan_vpn_profile_parcel_for_transport

        """
        pass

    def test_edit_aaa_profile_parcel_for_system(self):
        """Test case for edit_aaa_profile_parcel_for_system

        """
        pass

    def test_edit_banner_profile_parcel_for_system(self):
        """Test case for edit_banner_profile_parcel_for_system

        """
        pass

    def test_edit_basic_profile_parcel_for_system(self):
        """Test case for edit_basic_profile_parcel_for_system

        """
        pass

    def test_edit_bfd_profile_parcel_for_system(self):
        """Test case for edit_bfd_profile_parcel_for_system

        """
        pass

    def test_edit_cellular_controller_and_cellular_profile_parcel_association_for_transport(self):
        """Test case for edit_cellular_controller_and_cellular_profile_parcel_association_for_transport

        """
        pass

    def test_edit_cellular_controller_profile_parcel_for_transport(self):
        """Test case for edit_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_edit_cellular_profile_profile_parcel_for_transport(self):
        """Test case for edit_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_edit_config_profile_parcel_for_cli(self):
        """Test case for edit_config_profile_parcel_for_cli

        """
        pass

    def test_edit_global_profile_parcel_for_system(self):
        """Test case for edit_global_profile_parcel_for_system

        """
        pass

    def test_edit_lan_vpn_and_routing_bgp_parcel_association_for_service(self):
        """Test case for edit_lan_vpn_and_routing_bgp_parcel_association_for_service

        """
        pass

    def test_edit_lan_vpn_and_routing_ospf_parcel_association_for_service(self):
        """Test case for edit_lan_vpn_and_routing_ospf_parcel_association_for_service

        """
        pass

    def test_edit_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for edit_lan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_edit_lan_vpn_interface_ethernet_parcel_for_service(self):
        """Test case for edit_lan_vpn_interface_ethernet_parcel_for_service

        """
        pass

    def test_edit_lan_vpn_profile_parcel_for_service(self):
        """Test case for edit_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_edit_logging_profile_parcel_for_system(self):
        """Test case for edit_logging_profile_parcel_for_system

        """
        pass

    def test_edit_management_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for edit_management_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_edit_management_vpn_profile_parcel_for_transport(self):
        """Test case for edit_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_edit_ntp_profile_parcel_for_system(self):
        """Test case for edit_ntp_profile_parcel_for_system

        """
        pass

    def test_edit_omp_profile_parcel_for_system(self):
        """Test case for edit_omp_profile_parcel_for_system

        """
        pass

    def test_edit_routing_bgp_profile_parcel_for_service(self):
        """Test case for edit_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_edit_routing_ospf_profile_parcel_for_service(self):
        """Test case for edit_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_edit_sdwan_feature_profile(self):
        """Test case for edit_sdwan_feature_profile

        """
        pass

    def test_edit_sdwan_service_feature_profile(self):
        """Test case for edit_sdwan_service_feature_profile

        """
        pass

    def test_edit_sdwan_system_feature_profile(self):
        """Test case for edit_sdwan_system_feature_profile

        """
        pass

    def test_edit_sdwan_transport_feature_profile(self):
        """Test case for edit_sdwan_transport_feature_profile

        """
        pass

    def test_edit_tracker_profile_parcel_for_service(self):
        """Test case for edit_tracker_profile_parcel_for_service

        """
        pass

    def test_edit_tracker_profile_parcel_for_transport(self):
        """Test case for edit_tracker_profile_parcel_for_transport

        """
        pass

    def test_edit_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport(self):
        """Test case for edit_wan_vpn_interface_ethernet_and_tracker_parcel_association_for_transport

        """
        pass

    def test_edit_wan_vpn_interface_ethernet_parcel_for_transport(self):
        """Test case for edit_wan_vpn_interface_ethernet_parcel_for_transport

        """
        pass

    def test_edit_wan_vpn_profile_parcel_for_transport(self):
        """Test case for edit_wan_vpn_profile_parcel_for_transport

        """
        pass

    def test_get_aaa_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_aaa_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_aaa_profile_parcel_for_system(self):
        """Test case for get_aaa_profile_parcel_for_system

        """
        pass

    def test_get_banner_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_banner_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_banner_profile_parcel_for_system(self):
        """Test case for get_banner_profile_parcel_for_system

        """
        pass

    def test_get_basic_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_basic_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_basic_profile_parcel_for_system(self):
        """Test case for get_basic_profile_parcel_for_system

        """
        pass

    def test_get_bfd_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_bfd_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_bfd_profile_parcel_for_system(self):
        """Test case for get_bfd_profile_parcel_for_system

        """
        pass

    def test_get_cedge_system_global_parcel_schema_by_schema_type(self):
        """Test case for get_cedge_system_global_parcel_schema_by_schema_type

        """
        pass

    def test_get_cellular_controller_associated_cellular_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_cellular_controller_associated_cellular_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_cellular_controller_associated_cellular_profile_parcels_for_transport(self):
        """Test case for get_cellular_controller_associated_cellular_profile_parcels_for_transport

        """
        pass

    def test_get_cellular_controller_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_cellular_controller_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_cellular_controller_profile_parcel_for_transport(self):
        """Test case for get_cellular_controller_profile_parcel_for_transport

        """
        pass

    def test_get_cellular_profile_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_cellular_profile_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_cellular_profile_profile_parcel_for_transport(self):
        """Test case for get_cellular_profile_profile_parcel_for_transport

        """
        pass

    def test_get_config_profile_parcel_by_parcel_id_for_cli(self):
        """Test case for get_config_profile_parcel_by_parcel_id_for_cli

        """
        pass

    def test_get_config_profile_parcel_for_cli(self):
        """Test case for get_config_profile_parcel_for_cli

        """
        pass

    def test_get_global_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_global_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_global_profile_parcel_for_system(self):
        """Test case for get_global_profile_parcel_for_system

        """
        pass

    def test_get_interface_ethernet_parcels_for_service_lan_vpn(self):
        """Test case for get_interface_ethernet_parcels_for_service_lan_vpn

        """
        pass

    def test_get_interface_ethernet_parcels_for_transport_management_vpn(self):
        """Test case for get_interface_ethernet_parcels_for_transport_management_vpn

        """
        pass

    def test_get_interface_ethernet_parcels_for_transport_wan_vpn(self):
        """Test case for get_interface_ethernet_parcels_for_transport_wan_vpn

        """
        pass

    def test_get_lan_vpn_associated_routing_bgp_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_associated_routing_bgp_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_associated_routing_bgp_parcels_for_service(self):
        """Test case for get_lan_vpn_associated_routing_bgp_parcels_for_service

        """
        pass

    def test_get_lan_vpn_associated_routing_ospf_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_associated_routing_ospf_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_associated_routing_ospf_parcels_for_service(self):
        """Test case for get_lan_vpn_associated_routing_ospf_parcels_for_service

        """
        pass

    def test_get_lan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport(self):
        """Test case for get_lan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_lan_vpn_interface_ethernet_associated_tracker_parcels_for_transport(self):
        """Test case for get_lan_vpn_interface_ethernet_associated_tracker_parcels_for_transport

        """
        pass

    def test_get_lan_vpn_interface_ethernet_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_interface_ethernet_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_lan_vpn_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_lan_vpn_profile_parcel_for_service(self):
        """Test case for get_lan_vpn_profile_parcel_for_service

        """
        pass

    def test_get_logging_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_logging_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_logging_profile_parcel_for_system(self):
        """Test case for get_logging_profile_parcel_for_system

        """
        pass

    def test_get_management_vpn_interface_ethernet_parcel_by_parcel_id_for_transport(self):
        """Test case for get_management_vpn_interface_ethernet_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_management_vpn_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_management_vpn_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_management_vpn_profile_parcel_for_transport(self):
        """Test case for get_management_vpn_profile_parcel_for_transport

        """
        pass

    def test_get_ntp_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_ntp_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_ntp_profile_parcel_for_system(self):
        """Test case for get_ntp_profile_parcel_for_system

        """
        pass

    def test_get_omp_profile_parcel_by_parcel_id_for_system(self):
        """Test case for get_omp_profile_parcel_by_parcel_id_for_system

        """
        pass

    def test_get_omp_profile_parcel_for_system(self):
        """Test case for get_omp_profile_parcel_for_system

        """
        pass

    def test_get_routing_bgp_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_routing_bgp_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_routing_bgp_profile_parcel_for_service(self):
        """Test case for get_routing_bgp_profile_parcel_for_service

        """
        pass

    def test_get_routing_ospf_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_routing_ospf_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_routing_ospf_profile_parcel_for_service(self):
        """Test case for get_routing_ospf_profile_parcel_for_service

        """
        pass

    def test_get_sdwan_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_feature_profile_by_sdwan_family(self):
        """Test case for get_sdwan_feature_profile_by_sdwan_family

        """
        pass

    def test_get_sdwan_feature_profiles_by_family_and_type(self):
        """Test case for get_sdwan_feature_profiles_by_family_and_type

        """
        pass

    def test_get_sdwan_service_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_service_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_service_feature_profiles(self):
        """Test case for get_sdwan_service_feature_profiles

        """
        pass

    def test_get_sdwan_service_lan_vpn_interface_ethernet_parcel_schema_by_schema(self):
        """Test case for get_sdwan_service_lan_vpn_interface_ethernet_parcel_schema_by_schema

        """
        pass

    def test_get_sdwan_service_lan_vpn_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_lan_vpn_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_service_routing_bgp_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_routing_bgp_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_service_routing_ospf_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_routing_ospf_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_service_tracker_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_service_tracker_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_aaa_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_aaa_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_banner_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_banner_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_basic_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_basic_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_bfd_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_bfd_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_system_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_system_feature_profiles(self):
        """Test case for get_sdwan_system_feature_profiles

        """
        pass

    def test_get_sdwan_system_logging_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_logging_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_ntp_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_ntp_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_system_omp_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_system_omp_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_cellular_controller_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_cellular_controller_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_cellular_profile_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_cellular_profile_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_feature_profile_by_profile_id(self):
        """Test case for get_sdwan_transport_feature_profile_by_profile_id

        """
        pass

    def test_get_sdwan_transport_feature_profiles(self):
        """Test case for get_sdwan_transport_feature_profiles

        """
        pass

    def test_get_sdwan_transport_management_vpn_interface_ethernet_parcel_schema_by_schema(self):
        """Test case for get_sdwan_transport_management_vpn_interface_ethernet_parcel_schema_by_schema

        """
        pass

    def test_get_sdwan_transport_management_vpn_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_management_vpn_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_tracker_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_tracker_parcel_schema_by_schema_type

        """
        pass

    def test_get_sdwan_transport_wan_vpn_interface_ethernet_parcel_schema_by_schema(self):
        """Test case for get_sdwan_transport_wan_vpn_interface_ethernet_parcel_schema_by_schema

        """
        pass

    def test_get_sdwan_transport_wan_vpn_parcel_schema_by_schema_type(self):
        """Test case for get_sdwan_transport_wan_vpn_parcel_schema_by_schema_type

        """
        pass

    def test_get_tracker_profile_parcel_by_parcel_id_for_service(self):
        """Test case for get_tracker_profile_parcel_by_parcel_id_for_service

        """
        pass

    def test_get_tracker_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_tracker_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_tracker_profile_parcel_for_service(self):
        """Test case for get_tracker_profile_parcel_for_service

        """
        pass

    def test_get_tracker_profile_parcel_for_transport(self):
        """Test case for get_tracker_profile_parcel_for_transport

        """
        pass

    def test_get_wan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport(self):
        """Test case for get_wan_vpn_interface_ethernet_associated_tracker_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_wan_vpn_interface_ethernet_associated_tracker_parcels_for_transport(self):
        """Test case for get_wan_vpn_interface_ethernet_associated_tracker_parcels_for_transport

        """
        pass

    def test_get_wan_vpn_interface_ethernet_parcel_by_parcel_id_for_transport(self):
        """Test case for get_wan_vpn_interface_ethernet_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_wan_vpn_profile_parcel_by_parcel_id_for_transport(self):
        """Test case for get_wan_vpn_profile_parcel_by_parcel_id_for_transport

        """
        pass

    def test_get_wan_vpn_profile_parcel_for_transport(self):
        """Test case for get_wan_vpn_profile_parcel_for_transport

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_azure_connect_api import ConfigurationAzureConnectApi  # noqa: E501


class TestConfigurationAzureConnectApi(unittest.TestCase):
    """ConfigurationAzureConnectApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationAzureConnectApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_authenticate_azure_connect_cred_and_add(self):
        """Test case for authenticate_azure_connect_cred_and_add

        """
        pass

    def test_delete_wan_resource_groups(self):
        """Test case for delete_wan_resource_groups

        """
        pass

    def test_edit_wan_resource_groups(self):
        """Test case for edit_wan_resource_groups

        """
        pass

    def test_get_cortex_status(self):
        """Test case for get_cortex_status

        """
        pass

    def test_get_mapped_wan_resource_groups(self):
        """Test case for get_mapped_wan_resource_groups

        """
        pass

    def test_get_wan_resource_groups(self):
        """Test case for get_wan_resource_groups

        """
        pass

    def test_save_wan_resource_groups(self):
        """Test case for save_wan_resource_groups

        """
        pass

    def test_sync_wan_resource_groups(self):
        """Test case for sync_wan_resource_groups

        """
        pass


if __name__ == '__main__':
    unittest.main()
